from utils import wrapper as _


config = {
    # Concrete is Mozilla's example site.
    'mozilla-concrete': {
        'url': 'http://pay.dev.mozaws.net/',
        'terms': 'http://pay.dev.mozaws.net/terms/',
        'products': [
            {
                'id': 'brick',
                'description': _('Brick'),
                'amount': '10.00',
            },
            {
                'id': 'mortar',
                'description': _('Mortar'),
                'amount': '5.00',
                'img': ('https://raw.githubusercontent.com/mozilla'
                        '/payments-config/master/payments_config'
                        '/assets/mortar.png'),
            }
        ]
    }
}



import gettext

# All the locales we'll generate gettext files for.
possible_locales = [
    'ca', 'cs', 'cy', 'da', 'de', 'dsb', 'en', 'es', 'es_AR', 'es_CL',
    'et', 'eu', 'ff', 'fr', 'fy', 'he', 'hsb', 'hu', 'id', 'it', 'ja', 'ko',
    'lt', 'nb_NO', 'nl', 'pa', 'pl', 'pt', 'pt_BR', 'rm', 'ru', 'sk', 'sl',
    'sq', 'sr', 'sr_Latn', 'sv', 'sv_SE', 'tr', 'uk', 'zh_CN', 'zh_TW'
]

# For the moment, no locales are actually ready, we can loosen this up.
ready_locales = [
    'en'
]


class wrapper(object):
    """
    Wrap translated strings so they can be identified by the encoder.
    """

    def __init__(self, msg):
        self.msg = msg

    def __repr__(self):
        return gettext.gettext(self.msg)



from decimal import Decimal

import babel
from babel import numbers

from products import config
from payments_config.utils import ready_locales

products = {}
sellers = {}


class Seller(object):

    def __init__(self, id, config):
        self.id = id
        self.products = [Product(self.id, p) for p in config.pop('products')]

        # Check ids are unique.
        if self.id in sellers:
            raise ValueError('Repeated seller uid: {}'.format(self.id))

        for k, v in config.items():
            setattr(self, k, v)

        sellers[self.id] = self

    def to_dump(self):
        data = self.__dict__.copy()
        data.pop('products')
        return data


class Product(object):

    def __init__(self, id, config):
        # Provide some defaults.
        self.active = True
        self.currency = 'USD'
        self.img = ('https://raw.githubusercontent.com/mozilla'
                    '/payments-config/master/payments_config'
                    '/assets/default.png')

        self.id = id + '-' + config.pop('id')

        # Check ids are unique.
        if self.id in products:
            raise ValueError('Repeated product uid: {}'.format(self.id))

        for k, v in config.items():
            setattr(self, k, v)

        self.amount = Decimal(self.amount)

        self.price = self.format_prices(ready_locales)

        products[self.id] = self

    def format_prices(self, locales):
        prices = {}
        for locale in locales:
            try:
                prices[locale] = numbers.format_currency(
                    self.amount, self.currency, locale=locale)
            except babel.core.UnknownLocaleError:
                print 'Ignoring unknown locale: {}'.format(locale)
                continue

        return prices

    def to_dump(self):
        return self.__dict__


if not products and not sellers:
    for key, seller in config.items():
        Seller(key, seller)



import json
from setuptools import find_packages, setup


def get_version():
    """
    Return package version as in package.json.
    """
    return json.load(open('package.json', 'r'))['version']


setup(
    name='payments-config',
    version=get_version(),
    description='Payments Configuration',
    author='Andy McKay',
    author_email='andym@mozilla.com',
    license='BSD',
    packages=find_packages(),
    install_requires=('babel'),
    url='https://github.com/andymckay/payments-config',
    zip_safe=False,
)
